#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""This module contains project wide constants, variables and functions."""

from pcisim.lib.utils import *

#-----------------------------D E F A U L T S-------------------------------
#.Simulator
WINDOW_SIZE = (1024,600)
WINDOW_MINSIZE = (800, 600)             # This sets a minimum size
SIMULATION_DEFAULT_INTERVAL = 500
VIRTUAL_MEMORY_SIZE = 4*GB              # virtual memory for allocation
DEBUG_STEPS = False                     # if True, logs each step time

#.Theme
BACKGROUND_COLOR = '#444444'            # some panels background color
FOREGROUND_COLOR = "#FFFFFF"            # some panels foreground color
WIRE_COLOR = '#32CB25'                  # normal wire color
WIRE_WRITE_COLOR = '#FF2525'            # write mode wire color
WIRE_READ_COLOR = '#006AD2'             # read mode wire color
BUS_WIDTH = 15                          # graphical bus wire width
BUS_MARGIN = 16                         # graphical bus wire margin
PORT_WIDTH = 3                          # graphical port wire width
PORT_MARGIN = 6                         # graphical port wire margin
TABLE_PADDING = 2                       # DataView table padding
TABLE_BACKGROUND = BACKGROUND_COLOR     # DataView table background color
TABLE_FOREGROUND = FOREGROUND_COLOR     # DataView table foreground color
FIELD_NAME_BACKGROUND = "#CCCCCC"       # DataView field name foreground
FIELD_VALUE_BACKGROUND = "#FFFFFF"      # DataView field value foreground
FIELD_HIGHLIGHT_BACKGROUND = "#FFFF00"  # DataView 'hot' field background
TABLE_CONTROLS_SIZE = (90, 25)          # DataView textboxes,labels,.. sizes

#.Wireboard
BOARD_USIZE = (31,15)                   # size of the board in units
BOARD_SHOW_GRID = True                  # flag to show/hide the board
BOARD_GRID_COLOR = (245,245,245)        # color of the cells in the grid
BOARD_GRID_WIDTH = 1                    # width of the border of the cells

#.ActionsList
ACTLIST_MINWIDTH = 150
ACTLIST_MINHEIGHT = 100
ACTLIST_DEFAULT_WIDTH = 300
#.Paths
ASSETS_PATH = "./icons"

#----------------------------F U N C T I O N S------------------------------

def pickimage(imgname):
    """Get image name from images path.

    @PARAMS
        (str) imgname : filename containing the image

    @RETURN
        (str) resource path
    """
    return resource_path(imgname, ASSETS_PATH)
