#!/usr/bin/env python
# -*- coding: latin-1 -*-
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

""""This module contains information about BDF structure."""

from pcisim.lib.dataword import DataWord
__all__ = ['BDF']

class BDF(DataWord):
    """Implements a *Bus Device Function* data structure."""

    def __init__(self, bus=0, dev=0, func=0, reg=0x0):
        """
        @PARAMS
            (int) bus : bus number in range 0-255
            (int) dev : device number in range 0-31
            (int) func : function number in range 0-7
            (int) reg : register index in PCI Device Structure, range 0-255
        """
        super(BDF, self).__init__()
        self.add_field('register', 8, hint="ID registro a cui accedere")
        self.add_field('function', 3, hint="ID funzione selezionata")
        self.add_field('device', 5, hint="ID dispositivo connesso al bus")
        self.add_field('bus', 8, hint="Numero di bus in caso di bus multipli")
        self.add_field('reserved', 7, hint="Campo riservato")
        self.add_field('enable', 1, hint="Sempre impostato al valore 1")
        self.lock()

        self.set_field('bus', bus)
        self.set_field('device', dev)
        self.set_field('function', func)
        self.set_field('register', reg)
