#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Provides helper functions and global constants."""

import sys
import os

# SIZES
B = 1
KB = 1<<10
MB = 1<<20
GB = 1<<30
BINARY_SUFFIXES = ('B', 'KB', 'MB', 'GB')

# Format functions
def get_bin(value, bits):
    """Get binary representatio string.

    @PARAMS
        (int) value : value to represent
        (int) bits : number of bits for the value

    @RETURN
        (str) binary representation.
    """
    return bin(value)[2:].zfill(bits)

def get_hex(value, bits):
    """Get hexadecimal representatio string.

    @PARAMS
        (int) value : value to represent
        (int) bits : number of bits for the value

    @RETURN
        (str) hexadecimal representation.
    """
    h = hex(value).upper()[2:]
    if isinstance(value, long):
        h = h[:-1]
    return "0x" + h.zfill(bits/4)

#Adapted from http://stackoverflow.com/questions/14996453/python-libraries-to-calculate-human-readable-filesize-from-bytes
def humansize(bytesize):
    """Get an abbreviated string representation for a byte size."""
    if bytesize == 0: return '0 B'
    i = 0
    while bytesize >= 1024 and i < len(BINARY_SUFFIXES)-1:
        bytesize /= 1024.
        i += 1
    # Expand precision to 9 digits
    f = ('%.09f' % bytesize)[:-7].rstrip('0').rstrip('.')
    return '%s %s' % (f, BINARY_SUFFIXES[i])

def resource_path(resname, respath):
    """Get a resource path.

    @PARAMS
        resname : name of the resource file
        respath : relative path of the resource

    @RETURN
        (str) composed path.
    """
    # Possible future PyInstaller support
    if hasattr(sys, '_MEIPASS'):
        # PyInstaller >= 1.6
        d = os.path.join(sys._MEIPASS, respath)
    elif '_MEIPASS2' in os.environ:
        # PyInstaller < 1.6
        d = os.path.join(os.environ['_MEIPASS2'], respath)
    else:
        d = respath
    return os.path.join(d, resname)
