#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements an image widget."""

import wx
from .widget import Widget
from .unitsize import utopix
__all__ = ["ImageWidget"]

class ImageWidget(Widget):
    """A widget with an associated bitmap shown as background."""
    def __init__(self, parent, imgpath, upos=(0,0), usize=(1,1), **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (str) imgpath : image resource path
            (list[2]) upos : widget position in units
            (list[2]) usize : widget size in units
            (dict) kargs : wx.Panel additional parameters
        """
        self._img = wx.Image(imgpath, wx.BITMAP_TYPE_ANY)
        self._btm = None
        kargs.setdefault('transparent', True)
        super(ImageWidget, self).__init__(parent, upos, usize, **kargs)

#---------------------------P U B L I C   A P I-----------------------------

    def update_graphics(self, dc):
        """Draws background bitmap on the widget

        @NOTES
            bitmap is draw by this function because transparent image still
            needs background color.
        """
        dc.DrawBitmap(self._btm, 0,0)

    def GetSubBitmap(self, *args, **kargs):
        """Returns a subportion of the bitmap image.

        See 'wx.Bitmap.GetSubBitmap' for more details.
        """
        return self._btm.GetSubBitmap(*args, **kargs)

#---------------------------I N T E R N A L S-------------------------------

    def _doscale(self):
        # Panel
        self.SetSize( utopix(*self._usize) )
        self.SetPosition( utopix(*self._upos) )

        # Bitmap
        self._btm = wx.BitmapFromImage( self._img.Scale( *utopix(*self._usize) ) )
