#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements a label widget."""

import wx
from .widgetbase import WidgetBase
from .unitsize import utopix
__all__ = ['LabelWidget']

class LabelWidget(WidgetBase, wx.StaticText):
    """A label widget with scalable font size.

    @NOTES
        This widget is transparent to mouse clicks.
    """
    def __init__(self, parent, upos=(0,0), usize=(0.5,0.5), **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (list[2]) upos : widget position in units
            (list[2]) usize : widget size in units
            (dict) kargs : wx.StaticText additional parameters
        """
        wx.StaticText.__init__(self, parent, **kargs)
        WidgetBase.__init__(self, upos, usize)

#---------------------------I N T E R N A L S-------------------------------

    def _doscale(self):
        # Scales font and position
        curfont = self.GetFont()
        s = utopix(*self._usize)
        curfont.SetPixelSize( s )

        self.SetFont(curfont)
        self.SetPosition( utopix(*self._upos) )

    def _on_selection(self, evt=None):
        # Overrides this to skip selection
        parent = self.GetParent()
        if hasattr(parent, '_on_selection'):
            parent._on_selection()

#-------------------------------T E S T-------------------------------------

def _build(parent):
    lb = LabelWidget(parent, label='Test Label widget')
    return lb
