#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements a spin button widget."""

import wx
from .widgetbase import WidgetBase
from .unitsize import utopix
__all__ = ['SpinWidget']

class SpinWidget(WidgetBase, wx.SpinButton):
    """A spin button widget."""
    def __init__(self, parent, upos=(0,0), usize=(0.4,0.8), **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (list[2]) upos : widget position in units
            (list[2]) usize : widget size in units
            (dict) kargs : wx.SpinButton additional parameters
        """
        wx.SpinButton.__init__(self, parent, **kargs)
        WidgetBase.__init__(self, upos, usize)
        self.SetMinSize((0,0))

    def _doscale(self):
        self.SetPosition( utopix(*self._upos) )
        self.SetSize( utopix(*self._usize) )

_build = SpinWidget
