#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""A module to set, get and map unit sizes to pixel sizes."""

__all__ = ['utopix', 'set_unit_size', 'get_unit_size']

# This holds the current global unit size
_FIXED_UNIT_SIZE = 28

def utopix(*units):
    """Converts unit sizes to pixel sizes.

    @PARAMS
        | (float) units : a single unit to convert
        | (list*) units : multiple units to convert

    @RETURN
        | (float) single pixel size
        | (list) multiple pixel sizes
    """
    if len(units)==1:
        return units[0]*_FIXED_UNIT_SIZE
    else:
        res = []
        for unit in units:
            res.append(unit * _FIXED_UNIT_SIZE)
        return tuple(res)

def set_unit_size(newsize):
    """Changes global unit size.

    @PARAMS
        (list[2]) newsize : new unit size
    """
    global _FIXED_UNIT_SIZE
    _FIXED_UNIT_SIZE = newsize

def get_unit_size():
    """Gets current global unit size.

    @RETURN
        (list[2]) unit size as width,height
    """
    return _FIXED_UNIT_SIZE
