#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements a label with a background colour."""

import wx
__all__ = ['Label']

# Defaults
LABEL_FOREGROUND = "#222222"
LABEL_BACKGROUND = "#FFFFFF"

class Label(wx.TextCtrl):
    """A label with settable background color.

    This overcomes GTK+ limitation for wx.StaticText background.
    """
    def __init__(self, parent, label="", bgcolor=LABEL_BACKGROUND,
        fgcolor=LABEL_FOREGROUND, **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (str) label : initial value
            bgcolor : background label color
            fgcolor : foreground label color
            **kargs : additional parameters to pass to wx.TextCtrl
        """
        kargs['style'] = wx.TE_READONLY|wx.NO_BORDER
        kargs['value'] = label
        super(Label, self).__init__(parent, **kargs)

        self.SetForegroundColour(fgcolor)
        self.SetBackgroundColour(bgcolor)

def _build(parent):
    return Label(parent, label='Test label')
