#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements a StepSpin."""

import wx
from .stepctrl import StepCtrl, EVT_CONTROL_STEP
__all__ = ['StepSpin', 'EVT_CONTROL_STEP']

class StepSpin(wx.SpinCtrl, StepCtrl):
    """A spin control with stepping values.

    @EVENTS
        Fires EVT_CONTROL_STEP on value change.
    """
    def __init__(self, parent, step=1, **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (int) step : control step value
        """
        wx.SpinCtrl.__init__(self, parent, **kargs)
        StepCtrl.__init__(self, step)
        self.Bind(wx.EVT_SPINCTRL, self._do_all)

def _build(parent):
    s = StepSpin(parent, step=5)
    s.SetRange(-100,200)
    return s
