#!/usr/bin/env python
#
# Emanuele Faranda                                 <black.silver@hotmail.it>
#
#.....................P C I  B U S  S I M U L A T O R.......................
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#  MA 02110-1301, USA.
#...........................................................................
#

"""Implements a CPU."""

from pcisim.lib.widget import ImageWidget
from pcisim.core.locals import pickimage
__all__ = ['Cpu']

class Cpu(ImageWidget):
    """A widget which represents a CPU.

    @ATTRIBS
        (Port) port_config : configuration port linked to the northbridge
        (Port) port_data : data port linked to the northbridge

    @NOTES
        Use 'set_bridge_link' to enstablish link with northbridge.
    """
    def __init__(self, parent, upos=(0,0), **kargs):
        """
        @PARAMS
            (wx.Window) parent : parent window
            (list[2]) upos : position expressed in units
            **kargs : additional ImageWidget keyword arguments
        """
        kargs.setdefault('usize', (3,3))
        kargs['upos'] = upos
        kargs['imgpath'] = pickimage('cpu.png')
        kargs['selectable'] = False
        ImageWidget.__init__(self, parent, **kargs)
        self.SetBackgroundColour('black')

        # Bridge ports
        #  0xCF8 - CONFIG_ADDRESS
        self.port_config = None
        #  0xCFC - DATA_ADDRESS
        self.port_data = None

    def set_bridge_link(self, bridge):
        """Setup link to northbridge.

        @PARAMS
            bridge : northbridge instance.
        """
        # Link to bridge ports
        self.port_config = bridge.port_config
        self.port_data = bridge.port_data
        self.pcibus = bridge.pcibus

_build = Cpu
